Coverage report

File | function | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/pydantic_typer/__init__.py | (no function) | 1 | 0 | 0 | 0 | 0 | 100%
src/pydantic_typer/main.py | _flatten_pydantic_model | 18 | 0 | 0 | 10 | 1 | 96%
src/pydantic_typer/main.py | enable_pydantic | 18 | 0 | 0 | 6 | 0 | 100%
src/pydantic_typer/main.py | enable_pydantic.wrapper | 14 | 0 | 0 | 8 | 0 | 100%
src/pydantic_typer/main.py | (no function) | 14 | 0 | 0 | 0 | 0 | 100%
src/pydantic_typer/utils.py | deep_update | 7 | 0 | 0 | 6 | 0 | 100%
src/pydantic_typer/utils.py | inspect_signature | 4 | 1 | 0 | 2 | 1 | 67%
src/pydantic_typer/utils.py | (no function) | 7 | 0 | 1 | 0 | 0 | 100%
tests/__init__.py | (no function) | 0 | 0 | 0 | 0 | 0 | 100%
tests/test_001_basic.py | test_help | 2 | 0 | 0 | 0 | 0 | 100%
tests/test_001_basic.py | test_parse_pydantic_model | 3 | 0 | 0 | 0 | 0 | 100%
tests/test_001_basic.py | test_script | 2 | 0 | 0 | 0 | 0 | 100%
tests/test_001_basic.py | (no function) | 11 | 0 | 0 | 0 | 0 | 100%
tests/test_002_nested_models.py | test_help | 2 | 0 | 0 | 0 | 0 | 100%
tests/test_002_nested_models.py | test_parse_pydantic_model | 2 | 0 | 0 | 0 | 0 | 100%
tests/test_002_nested_models.py | test_script | 2 | 0 | 0 | 0 | 0 | 100%
tests/test_002_nested_models.py | (no function) | 11 | 0 | 0 | 0 | 0 | 100%
tests/test_003_annotated_argument copy.py | test_help | 2 | 0 | 0 | 0 | 0 | 100%
tests/test_003_annotated_argument copy.py | test_parse_pydantic_model | 3 | 0 | 0 | 0 | 0 | 100%
tests/test_003_annotated_argument copy.py | test_wrong_order | 3 | 0 | 0 | 0 | 0 | 100%
tests/test_003_annotated_argument copy.py | test_script | 2 | 0 | 0 | 0 | 0 | 100%
tests/test_003_annotated_argument copy.py | (no function) | 12 | 0 | 0 | 0 | 0 | 100%
tests/test_004_argument_override.py | test_help | 2 | 0 | 0 | 0 | 0 | 100%
tests/test_004_argument_override.py | test_parse_pydantic_model | 3 | 0 | 0 | 0 | 0 | 100%
tests/test_004_argument_override.py | test_script | 2 | 0 | 0 | 0 | 0 | 100%
tests/test_004_argument_override.py | (no function) | 11 | 0 | 0 | 0 | 0 | 100%
Total |  | 158 | 1 | 1 | 32 | 2 | 98%

No items found using the specified filter.